@@ -711,12 +711,16 @@ class FtApi:
         extension = "/v2/achievements/{}/achievements_users".format(achievement_id)
         return HttpMethod(extension, self.session, **kwargs)
         
+    def BlocsSquads(self, bloc_id, **kwargs):
+        extension = "/v2/blocs/{}/squads".format(bloc_id)
+        return HttpMethod(extension, self.session, **kwargs)
+        
     def BlocsScores(self, bloc_id, **kwargs):
         extension = "/v2/blocs/{}/scores".format(bloc_id)
         return HttpMethod(extension, self.session, **kwargs)
         
-    def BlocsSquads(self, bloc_id, **kwargs):
-        extension = "/v2/blocs/{}/squads".format(bloc_id)
+    def BlocsScores(self, bloc_id, id, **kwargs):
+        extension = "/v2/blocs/{}/scores/{}".format(bloc_id, id)
         return HttpMethod(extension, self.session, **kwargs)
         
     def BlocsCoalitions(self, bloc_id, **kwargs):
@@ -727,10 +731,6 @@ class FtApi:
         extension = "/v2/blocs/{}/squads/{}".format(bloc_id, id)
         return HttpMethod(extension, self.session, **kwargs)
         
-    def BlocsScores(self, bloc_id, id, **kwargs):
-        extension = "/v2/blocs/{}/scores/{}".format(bloc_id, id)
-        return HttpMethod(extension, self.session, **kwargs)
-        
     def BlocsSquads_users(self, bloc_id, **kwargs):
         extension = "/v2/blocs/{}/squads_users".format(bloc_id)
         return HttpMethod(extension, self.session, **kwargs)
@@ -743,20 +743,27 @@ class FtApi:
         extension = "/v2/blocs/{}/squads_users/{}".format(bloc_id, id)
         return HttpMethod(extension, self.session, **kwargs)
         
-    def CampusExams(self, campus_id, **kwargs):
-        extension = "/v2/campus/{}/exams".format(campus_id)
+    def CampusJournal(self, **kwargs):
+        """
+        More details: "https://api.intra.42.fr/apidoc/2.0/campusjournal.html"
+        """
+        extension = "/v2/campus/journal"
         return HttpMethod(extension, self.session, **kwargs)
         
-    def CampusUsers(self, campus_id, **kwargs):
-        extension = "/v2/campus/{}/users".format(campus_id)
+    def CampusNotes(self, campus_id, **kwargs):
+        extension = "/v2/campus/{}/notes".format(campus_id)
+        return HttpMethod(extension, self.session, **kwargs)
+        
+    def CampusExams(self, campus_id, **kwargs):
+        extension = "/v2/campus/{}/exams".format(campus_id)
         return HttpMethod(extension, self.session, **kwargs)
         
     def CampusStats(self, campus_id, **kwargs):
         extension = "/v2/campus/{}/stats".format(campus_id)
         return HttpMethod(extension, self.session, **kwargs)
         
-    def CampusNotes(self, campus_id, **kwargs):
-        extension = "/v2/campus/{}/notes".format(campus_id)
+    def CampusUsers(self, campus_id, **kwargs):
+        extension = "/v2/campus/{}/users".format(campus_id)
         return HttpMethod(extension, self.session, **kwargs)
         
     def CampusQuests(self, campus_id, **kwargs):
@@ -863,16 +870,12 @@ class FtApi:
         extension = "/v2/cursus/{}/teams".format(cursus_id)
         return HttpMethod(extension, self.session, **kwargs)
         
-    def CursusUsers(self, cursus_id, **kwargs):
-        extension = "/v2/cursus/{}/users".format(cursus_id)
-        return HttpMethod(extension, self.session, **kwargs)
-        
     def CursusExams(self, cursus_id, **kwargs):
         extension = "/v2/cursus/{}/exams".format(cursus_id)
         return HttpMethod(extension, self.session, **kwargs)
         
-    def CursusSkills(self, cursus_id, **kwargs):
-        extension = "/v2/cursus/{}/skills".format(cursus_id)
+    def CursusUsers(self, cursus_id, **kwargs):
+        extension = "/v2/cursus/{}/users".format(cursus_id)
         return HttpMethod(extension, self.session, **kwargs)
         
     def CursusLevels(self, cursus_id, **kwargs):
@@ -883,6 +886,10 @@ class FtApi:
         extension = "/v2/cursus/{}/events".format(cursus_id)
         return HttpMethod(extension, self.session, **kwargs)
         
+    def CursusSkills(self, cursus_id, **kwargs):
+        extension = "/v2/cursus/{}/skills".format(cursus_id)
+        return HttpMethod(extension, self.session, **kwargs)
+        
     def CursusQuests(self, cursus_id, **kwargs):
         extension = "/v2/cursus/{}/quests".format(cursus_id)
         return HttpMethod(extension, self.session, **kwargs)
@@ -996,13 +1003,6 @@ class FtApi:
         extension = "/v2/me"
         return HttpMethod(extension, self.session, **kwargs)
         
-    def MeTeams(self, **kwargs):
-        """
-        More details: "https://api.intra.42.fr/apidoc/2.0/meteams.html"
-        """
-        extension = "/v2/me/teams"
-        return HttpMethod(extension, self.session, **kwargs)
-        
     def MeSlots(self, **kwargs):
         """
         More details: "https://api.intra.42.fr/apidoc/2.0/meslots.html"
@@ -1010,6 +1010,13 @@ class FtApi:
         extension = "/v2/me/slots"
         return HttpMethod(extension, self.session, **kwargs)
         
+    def MeTeams(self, **kwargs):
+        """
+        More details: "https://api.intra.42.fr/apidoc/2.0/meteams.html"
+        """
+        extension = "/v2/me/teams"
+        return HttpMethod(extension, self.session, **kwargs)
+        
     def MeProjects(self, **kwargs):
         """
         More details: "https://api.intra.42.fr/apidoc/2.0/meprojects.html"
@@ -1086,14 +1093,14 @@ class FtApi:
         extension = "/v2/project_sessions/{}/scales".format(project_session_id)
         return HttpMethod(extension, self.session, **kwargs)
         
-    def Project_sessionsEvaluations(self, project_session_id, **kwargs):
-        extension = "/v2/project_sessions/{}/evaluations".format(project_session_id)
-        return HttpMethod(extension, self.session, **kwargs)
-        
     def Project_sessionsAttachments(self, project_session_id, **kwargs):
         extension = "/v2/project_sessions/{}/attachments".format(project_session_id)
         return HttpMethod(extension, self.session, **kwargs)
         
+    def Project_sessionsEvaluations(self, project_session_id, **kwargs):
+        extension = "/v2/project_sessions/{}/evaluations".format(project_session_id)
+        return HttpMethod(extension, self.session, **kwargs)
+        
     def Project_sessionsProject_data(self, project_session_id, **kwargs):
         extension = "/v2/project_sessions/{}/project_data".format(project_session_id)
         return HttpMethod(extension, self.session, **kwargs)
@@ -1126,14 +1133,6 @@ class FtApi:
         extension = "/v2/projects/{}/tags".format(project_id)
         return HttpMethod(extension, self.session, **kwargs)
         
-    def ProjectsExams(self, project_id, **kwargs):
-        extension = "/v2/projects/{}/exams".format(project_id)
-        return HttpMethod(extension, self.session, **kwargs)
-        
-    def ProjectsSlots(self, project_id, **kwargs):
-        extension = "/v2/projects/{}/slots".format(project_id)
-        return HttpMethod(extension, self.session, **kwargs)
-        
     def ProjectsUsers(self, project_id, **kwargs):
         extension = "/v2/projects/{}/users".format(project_id)
         return HttpMethod(extension, self.session, **kwargs)
@@ -1142,6 +1141,14 @@ class FtApi:
         extension = "/v2/projects/{}/teams".format(project_id)
         return HttpMethod(extension, self.session, **kwargs)
         
+    def ProjectsExams(self, project_id, **kwargs):
+        extension = "/v2/projects/{}/exams".format(project_id)
+        return HttpMethod(extension, self.session, **kwargs)
+        
+    def ProjectsSlots(self, project_id, **kwargs):
+        extension = "/v2/projects/{}/slots".format(project_id)
+        return HttpMethod(extension, self.session, **kwargs)
+        
     def ProjectsScales(self, project_id, **kwargs):
         extension = "/v2/projects/{}/scales".format(project_id)
         return HttpMethod(extension, self.session, **kwargs)
@@ -1154,16 +1161,16 @@ class FtApi:
         extension = "/v2/projects/{}/projects".format(project_id)
         return HttpMethod(extension, self.session, **kwargs)
         
-    def ProjectsAttachments(self, project_id, **kwargs):
-        extension = "/v2/projects/{}/attachments".format(project_id)
+    def ProjectsEvaluations(self, project_id, **kwargs):
+        extension = "/v2/projects/{}/evaluations".format(project_id)
         return HttpMethod(extension, self.session, **kwargs)
         
     def ProjectsScale_teams(self, project_id, **kwargs):
         extension = "/v2/projects/{}/scale_teams".format(project_id)
         return HttpMethod(extension, self.session, **kwargs)
         
-    def ProjectsEvaluations(self, project_id, **kwargs):
-        extension = "/v2/projects/{}/evaluations".format(project_id)
+    def ProjectsAttachments(self, project_id, **kwargs):
+        extension = "/v2/projects/{}/attachments".format(project_id)
         return HttpMethod(extension, self.session, **kwargs)
         
     def ProjectsProjects_users(self, project_id, **kwargs):
@@ -1244,14 +1251,14 @@ class FtApi:
         extension = "/v2/teams/{}/teams_users".format(team_id)
         return HttpMethod(extension, self.session, **kwargs)
         
-    def TeamsReset_team_uploads(self, id, **kwargs):
-        extension = "/v2/teams/{}/reset_team_uploads".format(id)
-        return HttpMethod(extension, self.session, **kwargs)
-        
     def TeamsTeams_uploads(self, team_id, **kwargs):
         extension = "/v2/teams/{}/teams_uploads".format(team_id)
         return HttpMethod(extension, self.session, **kwargs)
         
+    def TeamsReset_team_uploads(self, id, **kwargs):
+        extension = "/v2/teams/{}/reset_team_uploads".format(id)
+        return HttpMethod(extension, self.session, **kwargs)
+        
     def Teams_uploadsMultiple_create(self, **kwargs):
         """
         More details: "https://api.intra.42.fr/apidoc/2.0/teams_uploadsmultiple_create.html"
@@ -1263,14 +1270,14 @@ class FtApi:
         extension = "/v2/titles/{}/users".format(title_id)
         return HttpMethod(extension, self.session, **kwargs)
         
-    def TitlesTitles_users(self, title_id, **kwargs):
-        extension = "/v2/titles/{}/titles_users".format(title_id)
-        return HttpMethod(extension, self.session, **kwargs)
-        
     def TitlesAchievements(self, title_id, **kwargs):
         extension = "/v2/titles/{}/achievements".format(title_id)
         return HttpMethod(extension, self.session, **kwargs)
         
+    def TitlesTitles_users(self, title_id, **kwargs):
+        extension = "/v2/titles/{}/titles_users".format(title_id)
+        return HttpMethod(extension, self.session, **kwargs)
+        
     def TranslationsUpload(self, **kwargs):
         """
         More details: "https://api.intra.42.fr/apidoc/2.0/translationsupload.html"
@@ -1290,42 +1297,30 @@ class FtApi:
         extension = "/v2/users/{}/apps".format(user_id)
         return HttpMethod(extension, self.session, **kwargs)
         
-    def UsersSlots(self, user_id, **kwargs):
-        extension = "/v2/users/{}/slots".format(user_id)
-        return HttpMethod(extension, self.session, **kwargs)
-        
     def UsersNotes(self, user_id, **kwargs):
         extension = "/v2/users/{}/notes".format(user_id)
         return HttpMethod(extension, self.session, **kwargs)
         
-    def UsersExams(self, user_id, **kwargs):
-        extension = "/v2/users/{}/exams".format(user_id)
-        return HttpMethod(extension, self.session, **kwargs)
-        
-    def UsersRoles(self, user_id, **kwargs):
-        extension = "/v2/users/{}/roles".format(user_id)
-        return HttpMethod(extension, self.session, **kwargs)
-        
     def UsersTeams(self, user_id, **kwargs):
         extension = "/v2/users/{}/teams".format(user_id)
         return HttpMethod(extension, self.session, **kwargs)
         
+    def UsersExams(self, user_id, **kwargs):
+        extension = "/v2/users/{}/exams".format(user_id)
+        return HttpMethod(extension, self.session, **kwargs)
+        
+    def UsersSlots(self, user_id, **kwargs):
+        extension = "/v2/users/{}/slots".format(user_id)
+        return HttpMethod(extension, self.session, **kwargs)
+        
+    def UsersRoles(self, user_id, **kwargs):
+        extension = "/v2/users/{}/roles".format(user_id)
+        return HttpMethod(extension, self.session, **kwargs)
+        
     def UsersEvents(self, user_id, **kwargs):
         extension = "/v2/users/{}/events".format(user_id)
         return HttpMethod(extension, self.session, **kwargs)
         
-    def UsersTitles(self, user_id, **kwargs):
-        extension = "/v2/users/{}/titles".format(user_id)
-        return HttpMethod(extension, self.session, **kwargs)
-        
-    def UsersCloses(self, user_id, **kwargs):
-        extension = "/v2/users/{}/closes".format(user_id)
-        return HttpMethod(extension, self.session, **kwargs)
-        
-    def UsersScales(self, user_id, **kwargs):
-        extension = "/v2/users/{}/scales".format(user_id)
-        return HttpMethod(extension, self.session, **kwargs)
-        
     def UsersQuests(self, user_id, **kwargs):
         extension = "/v2/users/{}/quests".format(user_id)
         return HttpMethod(extension, self.session, **kwargs)
@@ -1334,14 +1329,26 @@ class FtApi:
         extension = "/v2/users/{}/groups".format(user_id)
         return HttpMethod(extension, self.session, **kwargs)
         
-    def UsersUnfreeze(self, user_id, **kwargs):
-        extension = "/v2/users/{}/unfreeze".format(user_id)
+    def UsersTitles(self, user_id, **kwargs):
+        extension = "/v2/users/{}/titles".format(user_id)
+        return HttpMethod(extension, self.session, **kwargs)
+        
+    def UsersScales(self, user_id, **kwargs):
+        extension = "/v2/users/{}/scales".format(user_id)
+        return HttpMethod(extension, self.session, **kwargs)
+        
+    def UsersCloses(self, user_id, **kwargs):
+        extension = "/v2/users/{}/closes".format(user_id)
         return HttpMethod(extension, self.session, **kwargs)
         
     def UsersMailings(self, user_id, **kwargs):
         extension = "/v2/users/{}/mailings".format(user_id)
         return HttpMethod(extension, self.session, **kwargs)
         
+    def UsersUnfreeze(self, user_id, **kwargs):
+        extension = "/v2/users/{}/unfreeze".format(user_id)
+        return HttpMethod(extension, self.session, **kwargs)
+        
     def UsersLocations(self, user_id, **kwargs):
         extension = "/v2/users/{}/locations".format(user_id)
         return HttpMethod(extension, self.session, **kwargs)
@@ -1354,36 +1361,20 @@ class FtApi:
         extension = "/v2/users/{}/patronages".format(user_id)
         return HttpMethod(extension, self.session, **kwargs)
         
-    def UsersExperiences(self, user_id, **kwargs):
-        extension = "/v2/users/{}/experiences".format(user_id)
-        return HttpMethod(extension, self.session, **kwargs)
-        
     def UsersInternships(self, user_id, **kwargs):
         extension = "/v2/users/{}/internships".format(user_id)
         return HttpMethod(extension, self.session, **kwargs)
         
-    def UsersScale_teams(self, user_id, **kwargs):
-        extension = "/v2/users/{}/scale_teams".format(user_id)
-        return HttpMethod(extension, self.session, **kwargs)
-        
     def UsersTeams_users(self, user_id, **kwargs):
         extension = "/v2/users/{}/teams_users".format(user_id)
         return HttpMethod(extension, self.session, **kwargs)
         
-    def UsersTransactions(self, user_id, **kwargs):
-        extension = "/v2/users/{}/transactions".format(user_id)
+    def UsersExperiences(self, user_id, **kwargs):
+        extension = "/v2/users/{}/experiences".format(user_id)
         return HttpMethod(extension, self.session, **kwargs)
         
-    def UsersCursus_users(self, user_id, **kwargs):
-        extension = "/v2/users/{}/cursus_users".format(user_id)
-        return HttpMethod(extension, self.session, **kwargs)
-        
-    def UsersCampus_users(self, user_id, **kwargs):
-        extension = "/v2/users/{}/campus_users".format(user_id)
-        return HttpMethod(extension, self.session, **kwargs)
-        
-    def UsersQuests_users(self, user_id, **kwargs):
-        extension = "/v2/users/{}/quests_users".format(user_id)
+    def UsersScale_teams(self, user_id, **kwargs):
+        extension = "/v2/users/{}/scale_teams".format(user_id)
         return HttpMethod(extension, self.session, **kwargs)
         
     def UsersEvents_users(self, user_id, **kwargs):
@@ -1398,14 +1389,30 @@ class FtApi:
         extension = "/v2/users/{}/groups_users".format(user_id)
         return HttpMethod(extension, self.session, **kwargs)
         
-    def UsersFree_past_agu(self, user_id, **kwargs):
-        extension = "/v2/users/{}/free_past_agu".format(user_id)
+    def UsersQuests_users(self, user_id, **kwargs):
+        extension = "/v2/users/{}/quests_users".format(user_id)
+        return HttpMethod(extension, self.session, **kwargs)
+        
+    def UsersTransactions(self, user_id, **kwargs):
+        extension = "/v2/users/{}/transactions".format(user_id)
+        return HttpMethod(extension, self.session, **kwargs)
+        
+    def UsersCampus_users(self, user_id, **kwargs):
+        extension = "/v2/users/{}/campus_users".format(user_id)
+        return HttpMethod(extension, self.session, **kwargs)
+        
+    def UsersCursus_users(self, user_id, **kwargs):
+        extension = "/v2/users/{}/cursus_users".format(user_id)
         return HttpMethod(extension, self.session, **kwargs)
         
     def UsersLocations(self, user_id, id, **kwargs):
         extension = "/v2/users/{}/locations/{}".format(user_id, id)
         return HttpMethod(extension, self.session, **kwargs)
         
+    def UsersFree_past_agu(self, user_id, **kwargs):
+        extension = "/v2/users/{}/free_past_agu".format(user_id)
+        return HttpMethod(extension, self.session, **kwargs)
+        
     def UsersProjects_users(self, user_id, **kwargs):
         extension = "/v2/users/{}/projects_users".format(user_id)
         return HttpMethod(extension, self.session, **kwargs)
@@ -1418,6 +1425,10 @@ class FtApi:
         extension = "/v2/users/{}/languages_users".format(user_id)
         return HttpMethod(extension, self.session, **kwargs)
         
+    def UsersUser_candidature(self, user_id, **kwargs):
+        extension = "/v2/users/{}/user_candidature".format(user_id)
+        return HttpMethod(extension, self.session, **kwargs)
+        
     def UsersExpertises_users(self, user_id, **kwargs):
         extension = "/v2/users/{}/expertises_users".format(user_id)
         return HttpMethod(extension, self.session, **kwargs)
@@ -1430,18 +1441,14 @@ class FtApi:
         extension = "/v2/users/{}/coalitions_users".format(user_id)
         return HttpMethod(extension, self.session, **kwargs)
         
-    def UsersUser_candidature(self, user_id, **kwargs):
-        extension = "/v2/users/{}/user_candidature".format(user_id)
+    def UsersCertificates_users(self, user_id, **kwargs):
+        extension = "/v2/users/{}/certificates_users".format(user_id)
         return HttpMethod(extension, self.session, **kwargs)
         
     def UsersPatronages_reports(self, user_id, **kwargs):
         extension = "/v2/users/{}/patronages_reports".format(user_id)
         return HttpMethod(extension, self.session, **kwargs)
         
-    def UsersCertificates_users(self, user_id, **kwargs):
-        extension = "/v2/users/{}/certificates_users".format(user_id)
-        return HttpMethod(extension, self.session, **kwargs)
-        
     def UsersLanguages_users(self, user_id, id, **kwargs):
         extension = "/v2/users/{}/languages_users/{}".format(user_id, id)
         return HttpMethod(extension, self.session, **kwargs)
